@@ -1,5 +1,5 @@
-// Copyright (C) 2009-2010 NICTA (www.nicta.com.au)
-// Copyright (C) 2009-2010 Conrad Sanderson
+// Copyright (C) 2009-2011 NICTA (www.nicta.com.au)
+// Copyright (C) 2009-2011 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -37,9 +37,11 @@ mean(const Row<eT>& A)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (A.n_elem == 0), "mean(): given vector has no elements" );
+  const u32 A_n_elem = A.n_elem;
   
-  return op_mean::direct_mean(A.mem, A.n_elem);
+  arma_debug_check( (A_n_elem == 0), "mean(): given object has no elements" );
+  
+  return op_mean::direct_mean(A.mem, A_n_elem);
   }
 
 
@@ -53,9 +55,11 @@ mean(const Col<eT>& A)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (A.n_elem == 0), "mean(): given vector has no elements" );
+  const u32 A_n_elem = A.n_elem;
   
-  return op_mean::direct_mean(A.mem, A.n_elem);
+  arma_debug_check( (A_n_elem == 0), "mean(): given object has no elements" );
+  
+  return op_mean::direct_mean(A.mem, A_n_elem);
   }
 
 
@@ -77,9 +81,11 @@ mean(const Op<T1, op_mean>& in)
   const unwrap<T1> tmp1(in.m);
   const Mat<eT>& X = tmp1.M;
   
-  arma_debug_check( (X.n_elem == 0), "mean(): given matrix has no elements" );
+  const u32 X_n_elem = X.n_elem;
   
-  return op_mean::direct_mean(X.mem, X.n_elem);
+  arma_debug_check( (X_n_elem == 0), "mean(): given object has no elements" );
+  
+  return op_mean::direct_mean(X.mem, X_n_elem);
   }
 
 
@@ -104,9 +110,11 @@ mean(const subview_row<eT>& A)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (A.n_elem == 0), "mean(): given vector has no elements" );
+  arma_debug_check( (A.n_elem == 0), "mean(): given object has no elements" );
   
-  return op_mean::direct_mean(A);
+  const eT mu = accu(A) / eT(A.n_cols);
+  
+  return is_finite(mu) ? mu : op_mean::direct_mean_robust(A);
   }
 
 
@@ -119,9 +127,9 @@ mean(const subview_col<eT>& A)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (A.n_elem == 0), "mean(): given vector has no elements" );
+  arma_debug_check( (A.n_elem == 0), "mean(): given object has no elements" );
   
-  return op_mean::direct_mean(A);
+  return op_mean::direct_mean(A.colptr(0), A.n_rows);
   }
 
 
@@ -137,7 +145,7 @@ mean(const Op<subview<eT>, op_mean>& in)
   
   const subview<eT>& X = in.m;
   
-  arma_debug_check( (X.n_elem == 0), "mean(): given matrix has no elements" );
+  arma_debug_check( (X.n_elem == 0), "mean(): given object has no elements" );
   
   return op_mean::direct_mean(X);
   }
@@ -152,7 +160,7 @@ mean(const diagview<eT>& A)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (A.n_elem == 0), "mean(): given vector has no elements" );
+  arma_debug_check( (A.n_elem == 0), "mean(): given object has no elements" );
   
   return op_mean::direct_mean(A);
   }
@@ -169,9 +177,11 @@ mean(const subview_elem1<eT,T1>& A)
   
   const Mat<eT> X(A);
   
-  arma_debug_check( (X.n_elem == 0), "mean(): given matrix has no elements" );
+  const u32 X_n_elem = X.n_elem;
   
-  return op_mean::direct_mean(X.mem, X.n_elem);
+  arma_debug_check( (X_n_elem == 0), "mean(): given object has no elements" );
+  
+  return op_mean::direct_mean(X.mem, X_n_elem);
   }
 
 
